@@ -29,11 +29,7 @@ sub instance {
 
 sub _initialize {
   my $class = shift;
-
-  my $cb;
-  if ( ref( $_[-1] ) eq 'CODE' ) {
-    $cb = pop;
-  }
+  my $cb    = pop if ref( $_[-1] ) eq 'CODE';
 
   my $bar_config = App::Environ::Config->instance->{'bar'};
 
@@ -51,10 +47,7 @@ sub _initialize {
 }
 
 sub _reload {
-  my $cb;
-  if ( ref( $_[-1] ) eq 'CODE' ) {
-    $cb = pop;
-  }
+  my $cb = pop if ref( $_[-1] ) eq 'CODE';
 
   $INSTANCE->{config} = App::Environ::Config->instance->{'bar'};
   $INSTANCE->{reload_cnt}++;
@@ -67,10 +60,7 @@ sub _reload {
 }
 
 sub _finalize {
-  my $cb;
-  if ( ref( $_[-1] ) eq 'CODE' ) {
-    $cb = pop;
-  }
+  my $cb = pop if ref( $_[-1] ) eq 'CODE';
 
   undef $INSTANCE;
 
